@@ -57,6 +57,7 @@ struct near_tag {
 
 	uint32_t n_records;
 	GList *records;
+	near_bool_t blank;
 
 	/* Tag specific structures */
 	struct {
@@ -260,6 +261,11 @@ static DBusMessage *write_ndef(DBusConnection *conn,
 
 	DBG("conn %p", conn);
 
+	if (tag->readonly == TRUE) {
+		DBG("Read only tag");
+		return __near_error_permission_denied(msg);
+	}
+
 	if (tag->write_msg)
 		return __near_error_in_progress(msg);
 
@@ -498,7 +504,7 @@ static int tag_initialize(struct near_tag *tag,
 	tag->target_idx = target_idx;
 	tag->protocol = protocols;
 	tag->n_records = 0;
-	tag->readonly = 0;
+	tag->readonly = FALSE;
 
 	if (nfcid_len <= NFC_MAX_NFCID1_LEN) {
 		tag->nfcid_len = nfcid_len;
@@ -696,16 +702,14 @@ int near_tag_add_records(struct near_tag *tag, GList *records,
 	return 0;
 }
 
-int near_tag_set_ro(struct near_tag *tag, near_bool_t readonly)
+void near_tag_set_ro(struct near_tag *tag, near_bool_t readonly)
 {
 	tag->readonly = readonly;
-
-	return 0;
 }
 
-near_bool_t near_tag_get_ro(struct near_tag *tag)
+void near_tag_set_blank(struct near_tag *tag, near_bool_t blank)
 {
-	return tag->readonly;
+	tag->blank = blank;
 }
 
 uint8_t *near_tag_get_data(struct near_tag *tag, size_t *data_length)
@@ -864,6 +868,7 @@ int __near_tag_write(struct near_tag *tag,
 				near_tag_io_cb cb)
 {
 	GSList *list;
+	int err;
 
 	DBG("type 0x%x", tag->type);
 
@@ -872,9 +877,20 @@ int __near_tag_write(struct near_tag *tag,
 
 		DBG("driver type 0x%x", driver->type);
 
-		if (driver->type == tag->type)
+		if (driver->type == tag->type) {
+			if (tag->blank == TRUE && driver->format != NULL) {
+				DBG("Blank tag detected, formatting");
+				err = driver->format(tag->adapter_idx,
+						tag->target_idx, NULL);
+
+				if (err < 0)
+					return err;
+
+			}
+
 			return driver->write(tag->adapter_idx, tag->target_idx,
 								ndef, cb);
+		}
 	}
 
 	return 0;
@@ -905,24 +921,14 @@ int __near_tag_check_presence(struct near_tag *tag, near_tag_io_cb cb)
 static void free_tag(gpointer data)
 {
 	struct near_tag *tag = data;
-	GList *list;
 
 	DBG("tag %p", tag);
 
-	for (list = tag->records; list; list = list->next) {
-		struct near_ndef_record *record = list->data;
+	near_ndef_records_free(tag->records);
 
-		__near_ndef_record_free(record);
-	}
-
-	DBG("record freed");
-
-	g_list_free(tag->records);
 	g_free(tag->path);
 	g_free(tag->data);
 	g_free(tag);
-
-	DBG("Done");
 }
 
 int __near_tag_init(void)
